@@ -9,9 +9,8 @@
 # Contact email: d.lowe@rl.ac.uk
 # =============================================================================
 
-from urllib.parse import urlencode
+from urllib.parse import urlencode, parse_qsl
 from owslib.etree import etree
-import cgi
 from owslib.util import Authentication, openURL
 
 
@@ -34,7 +33,7 @@ class ServiceException(Exception):
 class WCSBase(object):
     """Base class to be subclassed by version dependent WCS classes. Provides 'high-level'
     version independent methods"""
-    def __new__(self, url, xml, cookies, auth=None):
+    def __new__(self, url, xml, cookies, auth=None, timeout=30, headers=None):
         """ overridden __new__ method
 
         @type url: string
@@ -42,22 +41,28 @@ class WCSBase(object):
         @type xml: string
         @param xml: elementtree object
         @param auth: instance of owslib.util.Authentication
+        @param timeout: HTTP timeout, in seconds
+        @param headers: dict for geoserver's request's headers
         @return: inititalised WCSBase object
         """
         obj = object.__new__(self)
-        obj.__init__(url, xml, cookies, auth=auth)
+        obj.__init__(url, xml, cookies, auth=auth, headers=headers)
         self.cookies = cookies
+        self.headers = headers
+        self.timeout = timeout
         self._describeCoverage = {}  # cache for DescribeCoverage responses
         return obj
 
-    def __init__(self, auth=None):
+    def __init__(self, auth=None, timeout=30, headers=None):
         self.auth = auth or Authentication()
+        self.headers = headers
+        self.timeout = timeout
 
     def getDescribeCoverage(self, identifier):
         ''' returns a describe coverage document - checks the internal cache to see if it has been fetched before '''
         if identifier not in list(self._describeCoverage.keys()):
             reader = DescribeCoverageReader(
-                self.version, identifier, self.cookies, self.auth)
+                self.version, identifier, self.cookies, self.auth, self.timeout, self.headers)
             self._describeCoverage[identifier] = reader.read(self.url)
         return self._describeCoverage[identifier]
 
@@ -66,7 +71,7 @@ class WCSCapabilitiesReader(object):
     """Read and parses WCS capabilities document into a lxml.etree infoset
     """
 
-    def __init__(self, version=None, cookies=None, auth=None):
+    def __init__(self, version=None, cookies=None, auth=None, timeout=30, headers=None):
         """Initialize
         @type version: string
         @param version: WCS Version parameter e.g '1.0.0'
@@ -74,6 +79,8 @@ class WCSCapabilitiesReader(object):
         self.version = version
         self._infoset = None
         self.cookies = cookies
+        self.headers = headers
+        self.timeout = timeout
         self.auth = auth or Authentication()
 
     def capabilities_url(self, service_url):
@@ -85,7 +92,7 @@ class WCSCapabilitiesReader(object):
         """
         qs = []
         if service_url.find('?') != -1:
-            qs = cgi.parse_qsl(service_url.split('?')[1])
+            qs = parse_qsl(service_url.split('?')[1])
 
         params = [x[0] for x in qs]
 
@@ -110,7 +117,7 @@ class WCSCapabilitiesReader(object):
         @return: An elementtree tree representation of the capabilities document
         """
         request = self.capabilities_url(service_url)
-        u = openURL(request, timeout=timeout, cookies=self.cookies, auth=self.auth)
+        u = openURL(request, timeout=timeout, cookies=self.cookies, auth=self.auth, headers=self.headers)
         return etree.fromstring(u.read())
 
     def readString(self, st):
@@ -125,7 +132,7 @@ class DescribeCoverageReader(object):
     """Read and parses WCS DescribeCoverage document into a lxml.etree infoset
     """
 
-    def __init__(self, version, identifier, cookies, auth=None):
+    def __init__(self, version, identifier, cookies, auth=None, timeout=30, headers=None):
         """Initialize
         @type version: string
         @param version: WCS Version parameter e.g '1.0.0'
@@ -134,6 +141,8 @@ class DescribeCoverageReader(object):
         self._infoset = None
         self.identifier = identifier
         self.cookies = cookies
+        self.headers = headers
+        self.timeout = timeout
         self.auth = auth or Authentication()
 
     def descCov_url(self, service_url):
@@ -145,7 +154,7 @@ class DescribeCoverageReader(object):
         """
         qs = []
         if service_url.find('?') != -1:
-            qs = cgi.parse_qsl(service_url.split('?')[1])
+            qs = parse_qsl(service_url.split('?')[1])
 
         params = [x[0] for x in qs]
 
@@ -187,5 +196,5 @@ class DescribeCoverageReader(object):
         """
 
         request = self.descCov_url(service_url)
-        u = openURL(request, cookies=self.cookies, timeout=timeout, auth=self.auth)
+        u = openURL(request, cookies=self.cookies, timeout=timeout, auth=self.auth, headers=self.headers)
         return etree.fromstring(u.read())
